registerOverlayUi method
Registers a custom Flutter UI to be displayed in the overlay.
This method must be called before showOverlay to specify which Dart code will be executed when the overlay is shown.
Parameters:
entrypointFunctionName: The name of the Dart function to run (e.g., 'overlayMain')entrypointLibraryPath: The path to the Dart library containing the entrypoint (e.g., 'package:my_app/overlay_ui.dart')
Implementations should override this method to register the overlay UI with the platform-specific code.
Implementation
Future<void> registerOverlayUi({
required String entrypointFunctionName,
required String entrypointLibraryPath,
}) {
throw UnimplementedError('registerOverlayUi() has not been implemented.');
}